#!/usr/bin/env python3
#
# update-orc-dist-files.py ORC-FILE GENERATED-HEADER GENERATED-SOURCE
#
# Copies generated orc .c and .h files into source dir as -dist.[ch] backups,
# based on location of passed .orc file.
#
# Copyright (C) 2020 Tim-Philipp Müller <tim centricular com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
# Boston, MA 02110-1301, USA.

import shutil
import subprocess
import sys

assert (len(sys.argv) == 4)

orc_file = sys.argv[1]
gen_header = sys.argv[2]
gen_source = sys.argv[3]

# split off .orc suffix
assert (orc_file.endswith('.orc'))
orc_src_base = sys.argv[1][:-4]

# figure out names of disted backup files
dist_h = orc_src_base + "-dist.h"
dist_c = orc_src_base + "-dist.c"

# copy generated files from build dir into source dir
shutil.copyfile(gen_header, dist_h)
shutil.copyfile(gen_source, dist_c)

# run gst-indent on the .c files
subprocess.run(['gst-indent-1.0', dist_c])



#!/usr/bin/env python3
#
# meson-pkg-config-file-fixup.py PC_FILE VAR1,VAR2,VAR3
#
# Fix up escaping of custom variables in meson-generated .pc file
#
# Copyright (C) 2021 Tim-Philipp Müller <tim centricular com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
# Boston, MA 02110-1301, USA.

import os
import sys

if len(sys.argv) < 3:
  sys.exit('Usage: {} PC_FILE_BASE_NAME VAR1 [VAR2 [VAR3 ..]]'.format(sys.argv[0]))

pc_name = sys.argv[1]
pc_vars = sys.argv[2:]

build_root = os.environ['MESON_BUILD_ROOT']

# Poking into the private dir is not entirely kosher of course..
pc_files = [
  os.path.join(build_root, 'meson-private', pc_name + '.pc'),
  os.path.join(build_root, 'meson-uninstalled', pc_name + '-uninstalled.pc')
]

for pc_file in pc_files:
  out_lines = ''

  with open(pc_file, 'r') as f:
    for line in f:
      r = line.strip().split('=', 1)
      if len(r) == 2 and r[0] in pc_vars:
        out_lines += '{}={}\n'.format(r[0], r[1].replace('\\ ', ' '))
      else:
        out_lines += line

  with open(pc_file, 'w') as f_new:
      f_new.write(out_lines)

sys.exit(0)



#!/usr/bin/env python3

# This is in its own file rather than inside meson.build
# because a) mixing the two is ugly and b) trying to
# make special characters such as \n go through all
# backends is a fool's errand.

import sys, subprocess

h_array = ['--fhead',
           "#pragma once\n\n#include <gst/gst.h>\n#include <gst/gl/gstgl_fwd.h>\nG_BEGIN_DECLS\n",
           '--fprod',
           "\n/* enumerations from \"@basename@\" */\n",
           '--vhead',
           "GST_GL_API\nGType @enum_name@_get_type (void);\n#define GST_TYPE_@ENUMSHORT@ (@enum_name@_get_type())\n",
           '--ftail',
           "G_END_DECLS"
]

c_array = ['--fhead',
           "#ifdef HAVE_CONFIG_H\n#include \"config.h\"\n#endif\n#include \"gl-enumtypes.h\"\n\n#include <gst/gl/gl.h>\n\n#define C_ENUM(v) ((gint) v)\n#define C_FLAGS(v) ((guint) v)",
           '--fprod',
           "\n/* enumerations from \"@basename@\" */",
           '--vhead',
           "GType\n@enum_name@_get_type (void)\n{\n  static gsize static_g_define_type_id = 0;\n  if (g_once_init_enter (&static_g_define_type_id)) {\n    static const G@Type@Value values[] = {",
           '--vprod',
           "      { C_@TYPE@ (@VALUENAME@), \"@VALUENAME@\", \"@valuenick@\" },",
           '--vtail',
           "      { 0, NULL, NULL }\n    };\n    GType g_define_type_id = g_@type@_register_static (\"@EnumName@\", values);\n    g_once_init_leave (&static_g_define_type_id, g_define_type_id);\n  }\n  return static_g_define_type_id;\n}\n"
]

cmd = []
argn = 1
# Find the full command needed to run glib-mkenums
# On UNIX-like, this is just the full path to glib-mkenums
# On Windows, this is the full path to interpreter + full path to glib-mkenums
for arg in sys.argv[1:]:
    cmd.append(arg)
    argn += 1
    if arg.endswith('glib-mkenums') or arg.lower().endswith('glib-mkenums.exe'):
        break
ofilename = sys.argv[argn]
headers = sys.argv[argn + 1:]

if ofilename.endswith('.h'):
    arg_array = h_array
else:
    arg_array = c_array

cmd_array = cmd + arg_array + headers
pc = subprocess.Popen(cmd_array, stdout=subprocess.PIPE)
(stdo, _) = pc.communicate()
if pc.returncode != 0:
    sys.exit(pc.returncode)
open(ofilename, 'wb').write(stdo)
